#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-CKmqZXlXR7A7ok9gO3yOqf
key:                  lsp-2.2.0.0-CKmqZXlXR7A7ok9gO3yOqf
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  9c4e7498b8753844f04691b9a6736f67
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-4JSvcSZvElPG6BCzPDJKN:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-4JSvcSZvElPG6BCzPDJKN:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-4JSvcSZvElPG6BCzPDJKN:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-4JSvcSZvElPG6BCzPDJKN:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-CKmqZXlXR7A7ok9gO3yOqf
depends:
    aeson-2.2.1.0-CAI92PkToAUJ8bQ51mPxny
    async-2.2.5-1xX3vMN4zg36fgeIvJ9Q4V
    attoparsec-0.14.4-BV4n6FlglryAQUmumdJv0R base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-F3mwHEr5VLG5MWVuAMpEZ2
    containers-0.6.7 data-default-0.7.1.3-8w7fJ8RQ4j6IrMgdqaYpbC
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-1EYHMTe3sguJKzGBA0h7hZ
    lens-5.3.4-3woVa5Np0HKAfQlaeMGOUe
    lens-aeson-1.2.3-FRheumK30xMFYtN7IQjrGM
    lsp-types-2.0.2.0-4JSvcSZvElPG6BCzPDJKN mtl-2.3.1
    prettyprinter-1.7.1-GiZuScg817SGeNuRUeFCVg
    random-1.2.1.3-8xCOAhjQqZaHKyZvNvQjlZ
    row-types-1.0.1.2-Af75degXrx2HhR2fBQI1Km
    sorted-list-0.2.3.1-ArDKO2Lr87V3bmYK2f20S1 stm-2.5.1.0
    temporary-1.3-3Uec348YK1vIAXQsp8Wva5 text-2.0.2
    text-rope-0.3-EwIhZKbb3d49B5PqYbfRqD transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-BfuATd0ZFSGCCCUDlG7vl5
    uuid-1.3.16-rkTYpdguxhwc6ZExE3D9

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

